@@ -19,12 +19,15 @@
 
 #include "gdkx11device-xi2.h"
 #include "gdkdeviceprivate.h"
+#include "gdkdevice-xi2-private.h"
 
 #include "gdkintl.h"
 #include "gdkasync.h"
 #include "gdkprivate-x11.h"
 #include "gdkdisplay-x11.h"
 
+#include "gdk-private.h"
+
 #include <stdlib.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -74,12 +77,6 @@ static void gdk_x11_device_xi2_set_property (GObject      *object,
 static void gdk_x11_device_xi2_set_surface_cursor (GdkDevice *device,
                                                   GdkSurface *surface,
                                                   GdkCursor *cursor);
-static void gdk_x11_device_xi2_query_state (GdkDevice        *device,
-                                            GdkSurface        *surface,
-                                            GdkSurface       **child_surface,
-                                            double           *win_x,
-                                            double           *win_y,
-                                            GdkModifierType  *mask);
 
 static GdkGrabStatus gdk_x11_device_xi2_grab   (GdkDevice     *device,
                                                 GdkSurface     *surface,
@@ -113,7 +110,6 @@ gdk_x11_device_xi2_class_init (GdkX11DeviceXI2Class *klass)
   object_class->set_property = gdk_x11_device_xi2_set_property;
 
   device_class->set_surface_cursor = gdk_x11_device_xi2_set_surface_cursor;
-  device_class->query_state = gdk_x11_device_xi2_query_state;
   device_class->grab = gdk_x11_device_xi2_grab;
   device_class->ungrab = gdk_x11_device_xi2_ungrab;
   device_class->surface_at_position = gdk_x11_device_xi2_surface_at_position;
@@ -205,10 +201,9 @@ gdk_x11_device_xi2_set_surface_cursor (GdkDevice *device,
                       GDK_SURFACE_XID (surface));
 }
 
-static void
+void
 gdk_x11_device_xi2_query_state (GdkDevice        *device,
                                 GdkSurface        *surface,
-                                GdkSurface       **child_surface,
                                 double           *win_x,
                                 double           *win_y,
                                 GdkModifierType  *mask)
@@ -271,9 +266,6 @@ gdk_x11_device_xi2_query_state (GdkDevice        *device,
       XDestroyWindow (xdisplay, w);
     }
 
-  if (child_surface)
-    *child_surface = gdk_x11_surface_lookup_for_display (display, xchild_window);
-
   if (win_x)
     *win_x = xwin_x / scale;
 
@@ -770,7 +762,7 @@ gdk_x11_device_xi2_store_axes (GdkX11DeviceXI2 *device,
   g_free (device->last_axes);
 
   if (axes && n_axes)
-    device->last_axes = g_memdup (axes, sizeof (double) * n_axes);
+    device->last_axes = g_memdup2 (axes, sizeof (double) * n_axes);
   else
     device->last_axes = NULL;
 }
