@@ -399,6 +399,19 @@ get_group_active_button (GtkCheckButton *self)
   return NULL;
 }
 
+static void
+gtk_check_button_state_flags_changed (GtkWidget     *widget,
+                                      GtkStateFlags  previous_flags)
+{
+  GtkCheckButton *self = GTK_CHECK_BUTTON (widget);
+  GtkCheckButtonPrivate *priv = gtk_check_button_get_instance_private (self);
+  GtkStateFlags state = gtk_widget_get_state_flags (GTK_WIDGET (self));
+
+  gtk_widget_set_state_flags (priv->indicator_widget, state, TRUE);
+
+  GTK_WIDGET_CLASS (gtk_check_button_parent_class)->state_flags_changed (widget, previous_flags);
+}
+
 static gboolean
 gtk_check_button_focus (GtkWidget         *widget,
                         GtkDirectionType   direction)
@@ -475,10 +488,14 @@ gtk_check_button_focus (GtkWidget         *widget,
 }
 
 static void
-gtk_check_button_real_activate (GtkCheckButton *check_button)
+gtk_check_button_real_activate (GtkCheckButton *self)
 {
-  gtk_check_button_set_active (check_button,
-                               !gtk_check_button_get_active (check_button));
+  GtkCheckButtonPrivate *priv = gtk_check_button_get_instance_private (self);
+
+  if (priv->active && (priv->group_prev || priv->group_next))
+    return;
+
+  gtk_check_button_set_active (self, !gtk_check_button_get_active (self));
 }
 
 static void
@@ -499,6 +516,7 @@ gtk_check_button_class_init (GtkCheckButtonClass *class)
   object_class->set_property = gtk_check_button_set_property;
   object_class->get_property = gtk_check_button_get_property;
 
+  widget_class->state_flags_changed = gtk_check_button_state_flags_changed;
   widget_class->focus = gtk_check_button_focus;
 
   class->activate = gtk_check_button_real_activate;
@@ -915,7 +933,7 @@ gtk_check_button_set_label (GtkCheckButton *self,
  *
  * Setting up groups in a cycle leads to undefined behavior.
  *
- * Note that the same effect can be achieved via the [interface@Gtk.Actionable]
+ * Note that the same effect can be achieved via the [iface@Gtk.Actionable]
  * API, by using the same action with parameter type and state type 's'
  * for all buttons in the group, and giving each button its own target
  * value.
