@@ -58,7 +58,7 @@
  * is specified in the form of a tree model, and the display of the choices
  * can be adapted to the data in the model by using cell renderers, as you
  * would in a tree view. This is possible since `GtkComboBox` implements the
- * [interface@Gtk.CellLayout] interface. The tree model holding the valid
+ * [iface@Gtk.CellLayout] interface. The tree model holding the valid
  * choices is not restricted to a flat list, it can be a real tree, and the
  * popup will reflect the tree structure.
  *
@@ -731,7 +731,7 @@ gtk_combo_box_class_init (GtkComboBoxClass *klass)
                                                       P_("Entry Text Column"),
                                                       P_("The column in the combo box’s model to associate "
                                                          "with strings from the entry if the combo was "
-                                                         "created with #GtkComboBox:has-entry = %TRUE"),
+                                                         "created with GtkComboBox:has-entry = %TRUE"),
                                                       -1, G_MAXINT, -1,
                                                       GTK_PARAM_READWRITE|G_PARAM_EXPLICIT_NOTIFY));
 
@@ -1851,6 +1851,10 @@ gtk_combo_box_new (void)
  *
  * Creates a new empty `GtkComboBox` with an entry.
  *
+ * In order to use a combo box with entry, you need to tell it
+ * which column of the model contains the text for the entry
+ * by calling [method@Gtk.ComboBox.set_entry_text_column]. 
+ *
  * Returns: A new `GtkComboBox`
  */
 GtkWidget *
@@ -1885,6 +1889,8 @@ gtk_combo_box_new_with_model (GtkTreeModel *model)
  *
  * Creates a new empty `GtkComboBox` with an entry and a model.
  *
+ * See also [ctor@Gtk.ComboBox.new_with_entry].
+ *
  * Returns: A new `GtkComboBox`
  */
 GtkWidget *
@@ -1908,7 +1914,7 @@ gtk_combo_box_new_with_model_and_entry (GtkTreeModel *model)
  * [struct@Gtk.TreePath] of the active item.
  *
  * Returns: An integer which is the index of the currently active item,
- *     or -1 if there’s no active item.
+ *   or -1 if there’s no active item
  */
 int
 gtk_combo_box_get_active (GtkComboBox *combo_box)
@@ -2060,7 +2066,7 @@ gtk_combo_box_get_active_iter (GtkComboBox     *combo_box,
 /**
  * gtk_combo_box_set_active_iter:
  * @combo_box: A `GtkComboBox`
- * @iter: (allow-none): The `GtkTreeIter`, or %NULL
+ * @iter: (nullable): The `GtkTreeIter`
  *
  * Sets the current active item to be the one referenced by @iter.
  *
@@ -2084,7 +2090,7 @@ gtk_combo_box_set_active_iter (GtkComboBox     *combo_box,
 /**
  * gtk_combo_box_set_model: (attributes org.gtk.Method.set_property=model)
  * @combo_box: A `GtkComboBox`
- * @model: (allow-none): A `GtkTreeModel`
+ * @model: (nullable): A `GtkTreeModel`
  *
  * Sets the model used by @combo_box to be @model.
  *
@@ -2154,7 +2160,7 @@ out:
  * Returns the `GtkTreeModel` of @combo_box.
  *
  * Returns: (nullable) (transfer none): A `GtkTreeModel` which was passed
- *     during construction.
+ *   during construction.
  */
 GtkTreeModel *
 gtk_combo_box_get_model (GtkComboBox *combo_box)
@@ -2569,8 +2575,8 @@ gtk_combo_box_get_row_separator_func (GtkComboBox *combo_box)
  * gtk_combo_box_set_row_separator_func:
  * @combo_box: a `GtkComboBox`
  * @func: (nullable): a `GtkTreeViewRowSeparatorFunc`
- * @data: (allow-none): user data to pass to @func, or %NULL
- * @destroy: (allow-none): destroy notifier for @data, or %NULL
+ * @data: (nullable): user data to pass to @func
+ * @destroy: (nullable): destroy notifier for @data
  *
  * Sets the row separator function, which is used to determine
  * whether a row should be drawn as a separator.
@@ -2674,7 +2680,10 @@ gtk_combo_box_get_has_entry (GtkComboBox *combo_box)
  *   the internal entry
  *
  * Sets the model column which @combo_box should use to get strings
- * from to be @text_column.
+ * from to be @text_column. 
+ *
+ * For this column no separate 
+ * [class@Gtk.CellRenderer] is needed.
  *
  * The column @text_column in the model of @combo_box must be of
  * type %G_TYPE_STRING.
@@ -2848,7 +2857,7 @@ gtk_combo_box_get_id_column (GtkComboBox *combo_box)
  * not set, or if no row is active, or if the active row has a %NULL
  * ID value, then %NULL is returned.
  *
- * Returns: (nullable): the ID of the active row, or %NULL
+ * Returns: (nullable): the ID of the active row
  */
 const char *
 gtk_combo_box_get_active_id (GtkComboBox *combo_box)
@@ -2887,7 +2896,7 @@ gtk_combo_box_get_active_id (GtkComboBox *combo_box)
 /**
  * gtk_combo_box_set_active_id: (attributes org.gtk.Method.set_property=active-id)
  * @combo_box: a `GtkComboBox`
- * @active_id: (allow-none): the ID of the row to select, or %NULL
+ * @active_id: (nullable): the ID of the row to select
  *
  * Changes the active row of @combo_box to the one that has an ID equal to
  * @active_id.
@@ -2962,7 +2971,7 @@ gtk_combo_box_get_popup (GtkComboBox *combo_box)
 /**
  * gtk_combo_box_set_child: (attributes org.gtk.Method.set_property=child)
  * @combo_box: a `GtkComboBox`
- * @child: (allow-none): the child widget
+ * @child: (nullable): the child widget
  *
  * Sets the child widget of @combo_box.
  */
