@@ -31,7 +31,6 @@
 #include "gtkpopover.h"
 #include "gtkscrolledwindow.h"
 #include "gtkintl.h"
-#include "gtkprivate.h"
 #include "gtksearchentryprivate.h"
 #include "gtktext.h"
 #include "gtknative.h"
@@ -596,25 +595,13 @@ add_emoji (GtkWidget    *box,
   gtk_flow_box_insert (GTK_FLOW_BOX (box), child, prepend ? 0 : -1);
 }
 
-GBytes *
-get_emoji_data (void)
+static GBytes *
+get_emoji_data_by_language (const char *lang)
 {
   GBytes *bytes;
-  const char *lang;
-  char q[10];
   char *path;
   GError *error = NULL;
 
-  lang = pango_language_to_string (gtk_get_default_language ());
-  if (strchr (lang, '-'))
-    {
-      int i;
-      for (i = 0; lang[i] != '-' && i < 9; i++)
-        q[i] = lang[i];
-      q[i] = '\0';
-      lang = q;
-    }
-
   path = g_strconcat ("/org/gtk/libgtk/emoji/", lang, ".data", NULL);
   bytes = g_resources_lookup_data (path, 0, &error);
   if (bytes)
@@ -627,11 +614,15 @@ get_emoji_data (void)
   if (g_error_matches (error, G_RESOURCE_ERROR, G_RESOURCE_ERROR_NOT_FOUND))
     {
       char *filename;
+      char *gresource_name;
       GMappedFile *file;
 
       g_clear_error (&error);
 
-      filename = g_strconcat ("/usr/share/gtk-4.0/emoji/", lang, ".gresource", NULL);
+      gresource_name = g_strconcat (lang, ".gresource", NULL);
+      filename = g_build_filename (_gtk_get_data_prefix (), "share", "gtk-4.0",
+                                   "emoji", gresource_name, NULL);
+      g_clear_pointer (&gresource_name, g_free);
       file = g_mapped_file_new (filename, FALSE, NULL);
 
       if (file)
@@ -663,10 +654,40 @@ get_emoji_data (void)
     }
 
   g_clear_error (&error);
-
   g_free (path);
 
-  return g_resources_lookup_data ("/org/gtk/libgtk/emoji/en.data", 0, NULL);
+  return NULL;
+}
+
+GBytes *
+get_emoji_data (void)
+{
+  GBytes *bytes;
+  const char *lang;
+
+  lang = pango_language_to_string (gtk_get_default_language ());
+  bytes = get_emoji_data_by_language (lang);
+  if (bytes)
+    return bytes;
+
+  if (strchr (lang, '-'))
+    {
+      char q[5];
+      int i;
+
+      for (i = 0; lang[i] != '-' && i < 4; i++)
+        q[i] = lang[i];
+      q[i] = '\0';
+
+      bytes = get_emoji_data_by_language (q);
+      if (bytes)
+        return bytes;
+    }
+
+  bytes = get_emoji_data_by_language ("en");
+  g_assert (bytes);
+
+  return bytes;
 }
 
 static gboolean
