@@ -90,6 +90,9 @@ G_LOCK_DEFINE_STATIC (global_tables);
 static GSList *global_tables;
 
 static const guint16 gtk_compose_ignore[] = {
+  0, /* Yes, XKB will send us key press events with NoSymbol :( */
+  GDK_KEY_Overlay1_Enable,
+  GDK_KEY_Overlay2_Enable,
   GDK_KEY_Shift_L,
   GDK_KEY_Shift_R,
   GDK_KEY_Control_L,
@@ -302,10 +305,10 @@ gtk_im_context_simple_finalize (GObject *obj)
 /**
  * gtk_im_context_simple_new:
  * 
- * Creates a new #GtkIMContextSimple.
+ * Creates a new `GtkIMContextSimple`.
  *
- * Returns: a new #GtkIMContextSimple.
- **/
+ * Returns: a new `GtkIMContextSimple`
+ */
 GtkIMContext *
 gtk_im_context_simple_new (void)
 {
@@ -1077,9 +1080,12 @@ gtk_im_context_simple_reset (GtkIMContext *context)
 
   priv->compose_buffer[0] = 0;
 
-  if (priv->tentative_match->len > 0 || priv->in_hex_sequence)
+  if (priv->tentative_match->len > 0 ||
+      priv->in_hex_sequence ||
+      priv->in_compose_sequence)
     {
       priv->in_hex_sequence = FALSE;
+      priv->in_compose_sequence = FALSE;
       g_string_set_size (priv->tentative_match, 0);
       priv->tentative_match_len = 0;
       g_signal_emit_by_name (context_simple, "preedit-changed");
@@ -1183,7 +1189,7 @@ gtk_im_context_simple_get_preedit_string (GtkIMContext   *context,
 
 /**
  * gtk_im_context_simple_add_table: (skip)
- * @context_simple: A #GtkIMContextSimple
+ * @context_simple: A `GtkIMContextSimple`
  * @data: (array): the table
  * @max_seq_len: Maximum length of a sequence in the table
  * @n_seqs: number of sequences in the table
@@ -1216,7 +1222,7 @@ gtk_im_context_simple_add_table (GtkIMContextSimple *context_simple,
 
 /**
  * gtk_im_context_simple_add_compose_file:
- * @context_simple: A #GtkIMContextSimple
+ * @context_simple: A `GtkIMContextSimple`
  * @compose_file: The path of compose file
  *
  * Adds an additional table from the X11 compose file.
