@@ -38,11 +38,15 @@ typedef struct _GtkMenuButton        GtkMenuButton;
 
 /**
  * GtkMenuButtonCreatePopupFunc:
- * @menu_button: the #GtkMenuButton
+ * @menu_button: the `GtkMenuButton`
+ * @user_data: User data passed to gtk_menu_button_set_create_popup_func()
  *
- * User-provided callback function to create a popup for @menu_button on demand.
- * This function is called when the popup of @menu_button is shown, but none has
- * been provided via gtk_menu_button_set_popover() or gtk_menu_button_set_menu_model().
+ * User-provided callback function to create a popup for a
+ * `GtkMenuButton` on demand.
+ *
+ * This function is called when the popup of @menu_button is shown,
+ * but none has been provided via [method@Gtk.MenuButton.set_popover]
+ * or [method@Gtk.MenuButton.set_menu_model].
  */
 typedef void  (*GtkMenuButtonCreatePopupFunc) (GtkMenuButton *menu_button,
                                                gpointer       user_data);
@@ -70,12 +74,6 @@ void         gtk_menu_button_set_menu_model (GtkMenuButton *menu_button,
 GDK_AVAILABLE_IN_ALL
 GMenuModel  *gtk_menu_button_get_menu_model (GtkMenuButton *menu_button);
 
-GDK_AVAILABLE_IN_ALL
-void         gtk_menu_button_set_align_widget (GtkMenuButton *menu_button,
-                                               GtkWidget     *align_widget);
-GDK_AVAILABLE_IN_ALL
-GtkWidget   *gtk_menu_button_get_align_widget (GtkMenuButton *menu_button);
-
 GDK_AVAILABLE_IN_ALL
 void         gtk_menu_button_set_icon_name (GtkMenuButton *menu_button,
                                             const char    *icon_name);
@@ -111,6 +109,12 @@ void          gtk_menu_button_set_create_popup_func (GtkMenuButton
                                                      gpointer                      user_data,
                                                      GDestroyNotify                destroy_notify);
 
+GDK_AVAILABLE_IN_4_4
+void          gtk_menu_button_set_primary (GtkMenuButton *menu_button,
+                                           gboolean       primary);
+GDK_AVAILABLE_IN_4_4
+gboolean      gtk_menu_button_get_primary (GtkMenuButton *menu_button);
+
 G_END_DECLS
 
 #endif /* __GTK_MENU_BUTTON_H__ */
