@@ -31,7 +31,7 @@
 #include "gtkimage.h"
 #include "gtkintl.h"
 #include "gtkmarshalers.h"
-#include "gtkpasswordentrybufferprivate.h"
+#include "gtkpasswordentrybuffer.h"
 #include "gtkprivate.h"
 #include "gtkwidgetprivate.h"
 #include "gtkcsspositionvalueprivate.h"
@@ -142,7 +142,7 @@ focus_changed (GtkWidget *widget)
 
 /*< private >
  * gtk_password_entry_toggle_peek:
- * @entry: a #GtkPasswordEntry
+ * @entry: a `GtkPasswordEntry`
  *
  * Toggles the text visibility.
  */
@@ -549,11 +549,11 @@ gtk_password_entry_accessible_init (GtkAccessibleInterface *iface)
 
 /*< private >
  * gtk_password_entry_get_text_widget
- * @entry: a #GtkPasswordEntry
+ * @entry: a `GtkPasswordEntry`
  *
- * Retrieves the #GtkText delegate of the #GtkPasswordEntry.
+ * Retrieves the `GtkText` delegate of the `GtkPasswordEntry`.
  *
- * Returns: (transfer none): the #GtkText delegate widget
+ * Returns: (transfer none): the `GtkText` delegate widget
  */
 GtkText *
 gtk_password_entry_get_text_widget (GtkPasswordEntry *entry)
@@ -649,7 +649,7 @@ gtk_password_entry_get_show_peek_icon (GtkPasswordEntry *entry)
 /**
  * gtk_password_entry_set_extra_menu: (attributes org.gtk.Method.set_property=extra-menu)
  * @entry: a `GtkPasswordEntry`
- * @model: (allow-none): a `GMenuModel`
+ * @model: (nullable): a `GMenuModel`
  *
  * Sets a menu model to add when constructing
  * the context menu for @entry.
