@@ -208,6 +208,7 @@ struct _GtkSpinButton
 
   double         climb_rate;
   double         timer_step;
+  double         swipe_remainder;
 
   int            width_chars;
 
@@ -568,7 +569,7 @@ gtk_spin_button_class_init (GtkSpinButtonClass *class)
   /**
    * GtkSpinButton::change-value:
    * @spin_button: the object on which the signal was emitted
-   * @scroll: a #GtkScrollType to specify the speed and amount of change
+   * @scroll: a `GtkScrollType` to specify the speed and amount of change
    *
    * Emitted when the user initiates a value change.
    *
@@ -820,7 +821,7 @@ gtk_spin_button_get_property (GObject      *object,
        g_value_set_double (value, gtk_adjustment_get_value (spin_button->adjustment));
       break;
     case PROP_ORIENTATION:
-      g_value_set_enum (value, spin_button->orientation);
+      g_value_set_enum (value, gtk_orientable_get_orientation (GTK_ORIENTABLE (gtk_widget_get_layout_manager (GTK_WIDGET (spin_button)))));
       break;
     case PROP_EDITING_CANCELED:
       g_value_set_boolean (value, spin_button->editing_canceled);
@@ -838,6 +839,7 @@ swipe_gesture_begin (GtkGesture       *gesture,
 {
   gtk_gesture_set_state (gesture, GTK_EVENT_SEQUENCE_CLAIMED);
   gtk_widget_grab_focus (GTK_WIDGET (spin_button));
+  spin_button->swipe_remainder = 0;
 }
 
 static void
@@ -845,10 +847,12 @@ swipe_gesture_update (GtkGesture       *gesture,
                       GdkEventSequence *sequence,
                       GtkSpinButton    *spin_button)
 {
-  double vel_y;
+  double vel_y, step;
 
   gtk_gesture_swipe_get_velocity (GTK_GESTURE_SWIPE (gesture), NULL, &vel_y);
-  gtk_spin_button_real_spin (spin_button, -vel_y / 20);
+  step = (-vel_y / 20) + spin_button->swipe_remainder;
+  spin_button->swipe_remainder = fmod (step, gtk_adjustment_get_step_increment (spin_button->adjustment));
+  gtk_spin_button_real_spin (spin_button, step - spin_button->swipe_remainder);
 }
 
 static gboolean
@@ -1015,10 +1019,7 @@ gtk_spin_button_init (GtkSpinButton *spin_button)
   spin_button->snap_to_ticks = FALSE;
   spin_button->width_chars = -1;
 
-  spin_button->orientation = GTK_ORIENTATION_HORIZONTAL;
-
-  gtk_widget_update_orientation (GTK_WIDGET (spin_button),
-                                 spin_button->orientation);
+  gtk_widget_update_orientation (GTK_WIDGET (spin_button), GTK_ORIENTATION_HORIZONTAL);
 
   spin_button->entry = gtk_text_new ();
   gtk_editable_init_delegate (GTK_EDITABLE (spin_button));
@@ -1078,7 +1079,8 @@ gtk_spin_button_init (GtkSpinButton *spin_button)
                     G_CALLBACK (swipe_gesture_begin), spin_button);
   g_signal_connect (gesture, "update",
                     G_CALLBACK (swipe_gesture_update), spin_button);
-  gtk_widget_add_controller (GTK_WIDGET (spin_button), GTK_EVENT_CONTROLLER (gesture));
+  gtk_widget_add_controller (GTK_WIDGET (spin_button->entry),
+                             GTK_EVENT_CONTROLLER (gesture));
 
   controller = gtk_event_controller_scroll_new (GTK_EVENT_CONTROLLER_SCROLL_VERTICAL |
 				                GTK_EVENT_CONTROLLER_SCROLL_DISCRETE);
@@ -1200,21 +1202,23 @@ gtk_spin_button_set_orientation (GtkSpinButton  *spin,
   GtkBoxLayout *layout_manager;
   GtkEditable *editable = GTK_EDITABLE (spin->entry);
 
-  if (spin->orientation == orientation)
+  if (gtk_orientable_get_orientation (GTK_ORIENTABLE (spin)) == orientation)
     return;
 
-  spin->orientation = orientation;
-  gtk_widget_update_orientation (GTK_WIDGET (spin), spin->orientation);
+  layout_manager = GTK_BOX_LAYOUT (gtk_widget_get_layout_manager (GTK_WIDGET (spin)));
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (layout_manager), orientation);
+
+  gtk_widget_update_orientation (GTK_WIDGET (spin), orientation);
 
   /* change alignment if it's the default */
-  if (spin->orientation == GTK_ORIENTATION_VERTICAL &&
+  if (orientation == GTK_ORIENTATION_VERTICAL &&
       gtk_editable_get_alignment (editable) == 0.0)
     gtk_editable_set_alignment (editable, 0.5);
-  else if (spin->orientation == GTK_ORIENTATION_HORIZONTAL &&
+  else if (orientation == GTK_ORIENTATION_HORIZONTAL &&
            gtk_editable_get_alignment (editable) == 0.5)
     gtk_editable_set_alignment (editable, 0.0);
 
-  if (spin->orientation == GTK_ORIENTATION_HORIZONTAL)
+  if (orientation == GTK_ORIENTATION_HORIZONTAL)
     {
       /* Current orientation of the box is vertical! */
       gtk_widget_insert_after (spin->up_button, GTK_WIDGET (spin), spin->down_button);
@@ -1225,9 +1229,6 @@ gtk_spin_button_set_orientation (GtkSpinButton  *spin,
       gtk_widget_insert_before (spin->up_button, GTK_WIDGET (spin), spin->entry);
     }
 
-  layout_manager = GTK_BOX_LAYOUT (gtk_widget_get_layout_manager (GTK_WIDGET (spin)));
-  gtk_orientable_set_orientation (GTK_ORIENTABLE (layout_manager), spin->orientation);
-
   g_object_notify (G_OBJECT (spin), "orientation");
 }
 
@@ -1706,7 +1707,7 @@ gtk_spin_button_default_output (GtkSpinButton *spin_button)
  * gtk_spin_button_configure:
  * @spin_button: a `GtkSpinButton`
  * @adjustment: (nullable): a `GtkAdjustment` to replace the spin button’s
- *     existing adjustment, or %NULL to leave its current adjustment unchanged
+ *   existing adjustment, or %NULL to leave its current adjustment unchanged
  * @climb_rate: the new climb rate
  * @digits: the number of decimal places to display in the spin button
  *
@@ -1773,10 +1774,9 @@ gtk_spin_button_configure (GtkSpinButton *spin_button,
 
 /**
  * gtk_spin_button_new:
- * @adjustment: (allow-none): the `GtkAdjustment` that this spin
- *     button should use, or %NULL
+ * @adjustment: (nullable): the `GtkAdjustment` that this spin button should use
  * @climb_rate: specifies by how much the rate of change in the value will
- *     accelerate if you continue to hold down an up/down button or arrow key
+ *   accelerate if you continue to hold down an up/down button or arrow key
  * @digits: the number of decimal places to display
  *
  * Creates a new `GtkSpinButton`.
@@ -1964,8 +1964,8 @@ gtk_spin_button_set_increments (GtkSpinButton *spin_button,
 /**
  * gtk_spin_button_get_increments:
  * @spin_button: a `GtkSpinButton`
- * @step: (out) (allow-none): location to store step increment, or %NULL
- * @page: (out) (allow-none): location to store page increment, or %NULL
+ * @step: (out) (optional): location to store step increment
+ * @page: (out) (optional): location to store page increment
  *
  * Gets the current step and page the increments
  * used by @spin_button.
@@ -2019,8 +2019,8 @@ gtk_spin_button_set_range (GtkSpinButton *spin_button,
 /**
  * gtk_spin_button_get_range:
  * @spin_button: a `GtkSpinButton`
- * @min: (out) (optional): location to store minimum allowed value, or %NULL
- * @max: (out) (optional): location to store maximum allowed value, or %NULL
+ * @min: (out) (optional): location to store minimum allowed value
+ * @max: (out) (optional): location to store maximum allowed value
  *
  * Gets the range allowed for @spin_button.
  *
