@@ -184,7 +184,7 @@ gtk_toggle_button_mnemonic_activate (GtkWidget *widget,
    * gtk_widget_real_mnemonic_activate() in order to focus the widget even
    * if there is no mnemonic conflict.
    */
-  if (gtk_widget_get_can_focus (widget))
+  if (gtk_widget_get_focusable (widget))
     gtk_widget_grab_focus (widget);
 
   if (!group_cycling)
@@ -353,7 +353,7 @@ gtk_toggle_button_new_with_label (const char *label)
 /**
  * gtk_toggle_button_new_with_mnemonic:
  * @label: the text of the button, with an underscore in front of the
- *         mnemonic character
+ *   mnemonic character
  *
  * Creates a new `GtkToggleButton` containing a label.
  *
@@ -478,7 +478,7 @@ gtk_toggle_button_toggled (GtkToggleButton *toggle_button)
  *
  * Setting up groups in a cycle leads to undefined behavior.
  *
- * Note that the same effect can be achieved via the [interface@Gtk.Actionable]
+ * Note that the same effect can be achieved via the [iface@Gtk.Actionable]
  * API, by using the same action with parameter type and state type 's'
  * for all buttons in the group, and giving each button its own target
  * value.
