@@ -239,6 +239,11 @@ gtk_tree_expander_update_for_list_row (GtkTreeExpander *self)
             }
         }
 
+      /* The level property is >= 1 */
+      gtk_accessible_update_property (GTK_ACCESSIBLE (self),
+                                      GTK_ACCESSIBLE_PROPERTY_LEVEL, depth + 1,
+                                      -1);
+
       while (child)
         {
           GtkWidget *prev = gtk_widget_get_prev_sibling (child);
@@ -311,7 +316,7 @@ gtk_tree_expander_focus (GtkWidget        *widget,
   if (gtk_widget_is_focus (widget))
     return FALSE;
 
-  if (!gtk_widget_get_can_focus (widget))
+  if (!gtk_widget_get_focusable (widget))
     return FALSE;
 
   gtk_widget_grab_focus (widget);
@@ -704,7 +709,7 @@ gtk_tree_expander_get_child (GtkTreeExpander *self)
 /**
  * gtk_tree_expander_set_child: (attributes org.gtk.Method.set_property=child)
  * @self: a `GtkTreeExpander`
- * @child: (nullable): a `GtkWidget`, or %NULL
+ * @child: (nullable): a `GtkWidget`
  *
  * Sets the content widget to display.
  */
@@ -781,7 +786,7 @@ gtk_tree_expander_get_list_row (GtkTreeExpander *self)
 /**
  * gtk_tree_expander_set_list_row: (attributes org.gtk.Method.set_property=list-row)
  * @self: a `GtkTreeExpander` widget
- * @list_row: (nullable): a `GtkTreeListRow`, or %NULL
+ * @list_row: (nullable): a `GtkTreeListRow`
  *
  * Sets the tree list row that this expander should manage.
  */
