@@ -38,10 +38,16 @@
 #ifdef GDK_WINDOWING_X11
 #include "x11/gdkx.h"
 #include <epoxy/glx.h>
+#include <epoxy/egl.h>
 #endif
 
 #ifdef GDK_WINDOWING_WIN32
 #include "win32/gdkwin32.h"
+#include <epoxy/wgl.h>
+#endif
+
+#ifdef GDK_WIN32_ENABLE_EGL
+#include <epoxy/egl.h>
 #endif
 
 #ifdef GDK_WINDOWING_MACOS
@@ -247,7 +253,18 @@ append_glx_extension_row (GtkInspectorGeneral *gen,
 }
 #endif
 
-#ifdef GDK_WINDOWING_WAYLAND
+#ifdef GDK_WINDOWING_WIN32
+static void
+append_wgl_extension_row (GtkInspectorGeneral *gen,
+                          const char          *ext)
+{
+  HDC hdc = 0;
+
+  add_check_row (gen, GTK_LIST_BOX (gen->gl_box), ext, epoxy_has_wgl_extension (hdc, ext), 0);
+}
+#endif
+
+#if defined(GDK_WINDOWING_WAYLAND) || defined (GDK_WINDOWING_X11) || (defined (GDK_WINDOWING_WIN32) && defined(GDK_WIN32_ENABLE_EGL))
 static void
 append_egl_extension_row (GtkInspectorGeneral *gen,
                           EGLDisplay          dpy,
@@ -257,41 +274,27 @@ append_egl_extension_row (GtkInspectorGeneral *gen,
 }
 
 static EGLDisplay
-wayland_get_display (struct wl_display *wl_display)
+get_egl_display (GdkDisplay *display)
 {
-  EGLDisplay dpy = NULL;
-
-  if (epoxy_has_egl_extension (NULL, "EGL_KHR_platform_base"))
-    {
-      PFNEGLGETPLATFORMDISPLAYPROC getPlatformDisplay =
-        (void *) eglGetProcAddress ("eglGetPlatformDisplay");
-
-      if (getPlatformDisplay)
-        dpy = getPlatformDisplay (EGL_PLATFORM_WAYLAND_EXT,
-                                  wl_display,
-                                  NULL);
-      if (dpy)
-        return dpy;
-    }
-
-  if (epoxy_has_egl_extension (NULL, "EGL_EXT_platform_base"))
-    {
-      PFNEGLGETPLATFORMDISPLAYEXTPROC getPlatformDisplay =
-        (void *) eglGetProcAddress ("eglGetPlatformDisplayEXT");
-
-      if (getPlatformDisplay)
-        dpy = getPlatformDisplay (EGL_PLATFORM_WAYLAND_EXT,
-                                  wl_display,
-                                  NULL);
-      if (dpy)
-        return dpy;
-    }
-
-  return eglGetDisplay ((EGLNativeDisplayType)wl_display);
+#ifdef GDK_WINDOWING_WAYLAND
+  if (GDK_IS_WAYLAND_DISPLAY (display))
+    return gdk_wayland_display_get_egl_display (display);
+  else
+#endif
+#ifdef GDK_WINDOWING_X11
+  if (GDK_IS_X11_DISPLAY (display))
+    return gdk_x11_display_get_egl_display (display);
+  else
+#endif
+#ifdef GDK_WINDOWING_WIN32
+  if (GDK_IS_WIN32_DISPLAY (display))
+    return gdk_win32_display_get_egl_display (display);
+  else
+#endif
+   return NULL;
 }
 #endif
 
-
 static void
 init_gl (GtkInspectorGeneral *gen)
 {
@@ -302,12 +305,32 @@ init_gl (GtkInspectorGeneral *gen)
       return;
     }
 
+#if defined(GDK_WINDOWING_X11) || defined(GDK_WINDOWING_WAYLAND) || (defined(GDK_WINDOWING_WIN32) && defined(GDK_WIN32_ENABLE_EGL))
+  EGLDisplay egl_display = get_egl_display (gen->display);
+  if (egl_display)
+    {
+      char *version;
+
+      version = g_strconcat ("EGL ", eglQueryString (egl_display, EGL_VERSION), NULL);
+      gtk_label_set_text (GTK_LABEL (gen->gl_version), version);
+      g_free (version);
+
+      gtk_label_set_text (GTK_LABEL (gen->gl_vendor), eglQueryString (egl_display, EGL_VENDOR));
+
+      append_egl_extension_row (gen, egl_display, "EGL_KHR_create_context");
+      append_egl_extension_row (gen, egl_display, "EGL_EXT_buffer_age");
+      append_egl_extension_row (gen, egl_display, "EGL_EXT_swap_buffers_with_damage");
+      append_egl_extension_row (gen, egl_display, "EGL_KHR_surfaceless_context");
+    }
+  else
+#endif
 #ifdef GDK_WINDOWING_X11
   if (GDK_IS_X11_DISPLAY (gen->display))
     {
       Display *dpy = GDK_DISPLAY_XDISPLAY (gen->display);
       int error_base, event_base;
       char *version;
+
       if (!glXQueryExtension (dpy, &error_base, &event_base))
         return;
 
@@ -327,31 +350,23 @@ init_gl (GtkInspectorGeneral *gen)
     }
   else
 #endif
-#ifdef GDK_WINDOWING_WAYLAND
-  if (GDK_IS_WAYLAND_DISPLAY (gen->display))
+#ifdef GDK_WINDOWING_WIN32
+  if (GDK_IS_WIN32_DISPLAY (gen->display))
     {
-      EGLDisplay dpy;
-      EGLint major, minor;
+      int gl_version;
       char *version;
 
-      dpy = wayland_get_display (gdk_wayland_display_get_wl_display (gen->display));
-
-      if (!eglInitialize (dpy, &major, &minor))
-        {
-          gtk_label_set_text (GTK_LABEL (gen->gl_version), C_("GL version", "None"));
-          gtk_label_set_text (GTK_LABEL (gen->gl_vendor), C_("GL vendor", "None"));
-          return;
-        }
-
-      version = g_strconcat ("EGL ", eglQueryString (dpy, EGL_VERSION), NULL);
+      gl_version = epoxy_gl_version ();
+      version = g_strdup_printf ("WGL %d.%d", gl_version / 10, gl_version % 10, NULL);
       gtk_label_set_text (GTK_LABEL (gen->gl_version), version);
       g_free (version);
-      gtk_label_set_text (GTK_LABEL (gen->gl_vendor), eglQueryString (dpy, EGL_VENDOR));
+      gtk_label_set_text (GTK_LABEL (gen->gl_vendor), glGetString (GL_VENDOR));
 
-      append_egl_extension_row (gen, dpy, "EGL_KHR_create_context");
-      append_egl_extension_row (gen, dpy, "EGL_EXT_buffer_age");
-      append_egl_extension_row (gen, dpy, "EGL_EXT_swap_buffers_with_damage");
-      append_egl_extension_row (gen, dpy, "EGL_KHR_surfaceless_context");
+      append_wgl_extension_row (gen, "WGL_EXT_create_context");
+      append_wgl_extension_row (gen, "WGL_EXT_swap_control");
+      append_wgl_extension_row (gen, "WGL_OML_sync_control");
+      append_wgl_extension_row (gen, "WGL_ARB_pixel_format");
+      append_wgl_extension_row (gen, "WGL_ARB_multisample");
     }
   else
 #endif
